@@ -19,7 +19,7 @@ pub struct Goban {
     pub labels: HashMap<(u8, u8), String>,
 }
 
-#[derive(Debug, PartialEq, Eq, Clone, Copy, serde::Deserialize)]
+#[derive(Debug, PartialEq, Eq, Clone, Copy)]
 pub enum NodeDescription {
     Number(u64),
     Last,
@@ -56,7 +56,7 @@ impl Goban {
 
         match node_description {
             NodeDescription::Number(node_number) => {
-                for _ in 1..node_number {
+                for _ in 0..node_number {
                     sgf_node = sgf_node
                         .children()
                         .next()
